%% Evaluate (derivative of) piecewise collocation polynomial
% assuming all requested points are inside the collocation interval
% mesh([1,end]) (assertion is placed)
%
% (c) DDE-BIFTOOL v. 3.2a(298), 25/09/2018
%%
function [y,J]=dde_coll_eva(profile,mesh,x,degree,varargin)
%% INPUT:
%
% * profile: profile on mesh t
% * mesh: representation points in [t1,t2] size(m*l+1)
% * x: point(s) where to evaluate
% * degree: order polynomials
%% OUTPUT: 
%	y value of profile at x
%   J: sparse Jacobian:  y(:)=J*profile(:)
%
%% options
default={'kron',false,'diff',0,'sparse',true};
options=dde_set_options(default,varargin,'pass_on');
%% rescale mesh
tbd=mesh([1,end]);
tlen=tbd(2)-tbd(1);
mesh=(mesh-tbd(1))/tlen;
x=(x-tbd(1))/tlen;
mesh([1,end])=[0,1];
%% coarse mesh
tcoarse=mesh(1:degree:end);
nt=length(mesh);
nx=length(x);
%% find for each x the corresponding interpolation interval
% for x(i) the interval number is it(i) where it(i) points into mesh
it=dde_coll_subinterval(mesh,x);
itcoarse=floor((it-1)/degree)+1;
itcoarse(itcoarse==length(tcoarse))=length(tcoarse)-1;
assert(all(x>=0&x<=1));
%% evaluate Lagrange polynomials on all interpolation times
intlen=tcoarse(itcoarse+1)-tcoarse(itcoarse);
cscal=2*(x-tcoarse(itcoarse))./intlen-1;
%% evaluate barycentric weights
% for flexibility, (not assuming any particular interpolation grid)
[w,base_v,Dmat]=dde_coll_barywt(mesh,degree,options.diff);
%% calculate profiles
y=NaN(size(profile,1),length(x));
ti_m=(itcoarse-1)*degree+1;
jac_ind=NaN((degree+1),nx,2);
jac_vals=zeros(degree+1,nx);
for i=1:nx
    ix=ti_m(i)+(0:degree)';
    jac_ind(:,i,1)=i;
    jac_ind(:,i,2)=ix;
    fac=w./(cscal(i)-base_v);
    if any(isinf(fac))
        isel=it(i)-ti_m(i)+1;
        jac_vals(isel,i)=1;
    else
        jac_vals(:,i)=fac/sum(fac);
    end
    jac_vals(:,i)=Dmat'*jac_vals(:,i)/(intlen(i)*tlen)^options.diff;
    y(:,i)=profile(:,ix)*jac_vals(:,i);
end
%% return Jacobian if requested
if nargout>1
    jac_ind=reshape(jac_ind,[],2);
    jac_vals=jac_vals(:);
    iremove=jac_vals==0;
    jac_vals=jac_vals(~iremove);
    jac_ind=jac_ind(~iremove,:);
    J=sparse(jac_ind(:,1),jac_ind(:,2),jac_vals,nx,nt);
    if options.kron
       J=kron(J,speye(size(y,1)));
    end
    if ~options.sparse
        J=full(J);
    end
end
end
