function [Mfun,n_ext,MPfun]=dde_psol_monodromy(J,closest)
%% return monodromy matrix in functional form from collocation Jacobian
%
% Input
%
% * J: jacobian from dde_coll_jac extended into the past as far as
% necessary
% * closest (optional): if present create function for (M-c)^(-1)
%
% Output
%
% * Mfun(x): applies monodromy matrix to vector x of length n_ext, returns
% vector of length n_ext
% * n_ext: length of history vector
% * MPfun(x): applies monodromy matrix to vector x of length n_ext, returns
% (longer) vector of length size(J,2)
%
% (c) DDE-BIFTOOL v. 3.2a(309), 28/10/2018
%%
[s1,s2]=size(J);
n_ext=s2-s1;
n2_ext=max(n_ext-s1,0);
B=blkdiag(speye(n2_ext),J(1:s1,n_ext+1:s2));
Atop=cat(2,sparse(n2_ext,s1),speye(n2_ext));
A=cat(1,Atop(:,1:n_ext),-J(1:s1,1:n_ext)); % s1 x n_ext
Ptau=cat(2,sparse(n_ext,max(0,2*s1-s2)),speye(n_ext));
[Lm,Um,Pm,Qm,Rm]=lu(B);
if nargin>1 && ~isempty(closest)
    M_ext=[-closest*speye(n_ext),Ptau; -A, B];
    P_res=[speye(n_ext),sparse(n_ext,size(B,1))];
    [L,U,P,Q,R]=lu(M_ext);
    Mfun=@(x)P_res*(Q*(U\(L\(P*(R\([x;zeros(size(B,1),size(x,2))]))))));
else 
    Mfun=@(x)Ptau*(Qm*(Um\(Lm\(Pm*(Rm\(A*x))))));
end
MPfun=@(x)cat(1,x,Qm(end-s1+1:end,:)*(Um\(Lm\(Pm*(Rm\(A*x))))));
end
