function y=sys_rhs_POfold(x,p,beta,period,tau,sys_rhs,dim,xtau_ind,sys_deri)
%% rhs of extended DDE for fold of periodic orbits
% tau contains delays ([0,p(sys_tau())]), 
% xtau_ind(i,:) contains which columns of x(1:dim,:) correspond to
% x(tau(i)+tau(1:end))
% argument sys_deri can be either numeric (say, 1e-3, then a
% finite-difference approximation is used for the linearized system), or a
% function providing the partial derivatives of the DDE's sys_rhs
%
% (c) DDE-BIFTOOL v. 3.2a(309), 28/10/2018
%

xall=x(1:dim,:,:);
x0=xall(:,xtau_ind(1,:),:);
v=x(dim+1:end,xtau_ind(1,:),:);
y0=sys_rhs(x0,p);
if isnumeric(sys_deri) 
    %% no user-provided derivative (sys_deri is size of deviation)
    df=@(x0,dev,ind)app_dir_deriv(@(x)sys_rhs(x,p),x0,dev,ind,sys_deri);
else
    %% sys_deri is user-provided function
    df=@(x0,dev,ind)VAopX(sys_deri(x0,p,ind-1,[],[]),dev,'*');
end
%% partial derivative wrt non-delayed term
y1=beta/period*y0+reshape(df(x0,v(:,1,:),1),size(y0));
%% add partial derivatives of all delayed terms
for i=2:size(x0,2)
    fdev=sys_rhs(xall(:,xtau_ind(i,:),:),p)*tau(i)*beta/period;
    deviation=v(:,i,:)+reshape(fdev,dim,1,[]);
    y1=y1+reshape(df(x0,deviation,i),size(y0));
end
y=cat(1,y0,y1);
end
