%% Congestion control model
% generate right-hand side and derivatives from symbolic expressions %
% From: Hollot, C. V. and Chait, Y.
% Nonlinear stability analysis for a class of TCP/AQM networks
% Proceedings of the 40th IEEE Conference on Decision and Control, % 3:2309-2314, 2001
%
%% Differential equations
%
% $$\dot w(t)=1-\frac{w(t) w(t-1)}{2} k q(t-1),$$
%
% $$\dot q(t)=w(t)-c.$$
%
% Parameters are (in this order) |k|, |c|, |tau|
%% Add paths and load sym package if GNU Octave is used
clear
ddebiftoolpath='../../'; addpath(strcat(ddebiftoolpath,'ddebiftool'),...
strcat(ddebiftoolpath,'ddebiftool_extra_symbolic')); if dde_isoctave()
    pkg load symbolic
end
%% Create parameter names as strings and define fixed parameters
% The demo has the parameters |k|, |c| and |tau|
parnames={'k','c','tau'};
%% Create symbols for parameters, states and delays states
% The array |par| is the array of symbols in the same order as parnames. % Due to the following two lines we may, for example, use either k or
% par(1) to refer to the delay.
syms(parnames{:});       % create symbols for k, c and tua
par=cell2sym(parnames);  % now gamma is par(1) etc
%% Define system using symbolic algebra
syms w wtau q qtau % create symbols for w(t) w(t-tau), q(t), q(t-tau) 
dw_dt=1-w*wtau/2*k*qtau;
dq_dt=w-c;
%% Differentiate and generate code
[fstr,derivs]=dde_sym2funcs(...
[dw_dt;dq_dt],... % n x 1 array of derivative symbolic expressions 
[w,wtau;q,qtau],... % n x (ntau+1) array of symbols for states 
par,... % 1 x np (or np x 1) array of symbols used for parameters 
'filename','sym_congestionControlModel'); % argument output file